.. currentmodule:: abjad.tools.instrumenttools

transpose_from_written_pitch_to_sounding_pitch
==============================================

.. autofunction:: transpose_from_written_pitch_to_sounding_pitch
